import { COMPANY_NAME, CONTACT_INFO, LEGAL_DISCLAIMER } from "@/lib/constants";
import { Separator } from "@/components/ui/separator";
import { Button } from "@/components/ui/button";
import { Star, Facebook, Twitter } from "lucide-react";
import { Link } from "@/components/ui/link";
import logo from "@/Images/bjmckenna-solicitors-logo.png";

export default function Footer() {
  const quickLinks = [
    { name: "Legal Services", href: "/services" },
    { name: "About Us", href: "/about" },
    { name: "News & Insights", href: "/Insights" },
    { name: "Contact", href: "/contact" },
    { name: "Book Consultation", href: "/consultation" },
  ];

  const legalLinks = [
    { name: "Privacy Policy", href: "/legal/privacy-policy" },
    { name: "Terms of Use", href: "/legal/terms" },
    { name: "Complaints Handling", href: "https://mchaleandco.co.uk/complaints-handling/" },
  ];

  return (
    <footer className="bg-gray-50 border-t">
      <div className="container mx-auto px-6 py-12">
        <div className="grid grid-cols-1 md:grid-cols-12 gap-8">
          {/* Company Info & Social */}
          <div className="md:col-span-4">
            <div className="mb-4">
              <img 
                src={logo} 
                alt="BJ McKenna Solicitors Logo"
                className="h-12"
                width={200}
                height={48}
              />
            </div>
            <div className="grid gap-4 min-h-[120px]">
              {CONTACT_INFO.offices.map((office, index) => (
                <div 
                  key={index} 
                  className="text-sm text-gray-600"
                >
                  <p className="font-medium mb-1">{office.name}</p>
                  <address className="not-italic whitespace-pre-wrap">
                    {office.address}
                  </address>
                </div>
              ))}
            </div>
            <div className="space-y-3 mt-6">
              <Button
                className="w-full flex items-center justify-center gap-2"
                variant="outline"
                onClick={() => window.open('https://g.page/r/CTH8okp8L5gkEAE/review', '_blank')}
              >
                <Star className="w-4 h-4" />
                Leave us a review
              </Button>
              <div className="flex gap-3">
                <Button
                  variant="outline"
                  size="icon"
                  className="flex-1"
                  onClick={() => window.open('https://www.facebook.com/profile.php?id=100086661573469', '_blank')}
                >
                  <Facebook className="w-4 h-4" />
                  <span className="sr-only">Facebook</span>
                </Button>
                <Button
                  variant="outline"
                  size="icon"
                  className="flex-1"
                  onClick={() => window.open('https://x.com/bjmckennaco', '_blank')}
                >
                  <Twitter className="w-4 h-4" />
                  <span className="sr-only">X (Twitter)</span>
                </Button>
              </div>
            </div>
          </div>

          {/* Quick Links */}
          <div className="md:col-span-3">
            <h4 className="font-semibold text-gray-900 mb-4">Quick Links</h4>
            <ul className="space-y-2.5">
              {quickLinks.map((link) => (
                <li key={link.href}>
                  <Link 
                    href={link.href}
                    className="text-sm text-gray-600 hover:text-primary transition-colors"
                  >
                    {link.name}
                  </Link>
                </li>
              ))}
            </ul>
          </div>

          {/* Contact Info */}
          <div className="md:col-span-2">
            <h4 className="font-semibold text-gray-900 mb-4">Contact</h4>
            <ul className="space-y-2.5 text-sm text-gray-600">
              <li>
                <Link href={`tel:${CONTACT_INFO.phone}`} className="hover:text-primary transition-colors">
                  Tel: {CONTACT_INFO.phone}
                </Link>
              </li>
              <li>
                <Link href={`mailto:${CONTACT_INFO.email}`} className="hover:text-primary transition-colors">
                  Email: {CONTACT_INFO.email}
                </Link>
              </li>
              <li>
                <Link href="/about/locations" className="hover:text-primary transition-colors">
                  Find our offices
                </Link>
              </li>
            </ul>
          </div>

          {/* Legal */}
          <div className="md:col-span-3">
            <h4 className="font-semibold text-gray-900 mb-4">Legal</h4>
            <p className="text-xs text-gray-500 mb-4">{LEGAL_DISCLAIMER}</p>
            <ul className="space-y-2.5">
              {legalLinks.map((link) => (
                <li key={link.href}>
                  <Link 
                    href={link.href}
                    className="text-sm text-gray-400 hover:text-primary transition-colors"
                  >
                    {link.name}
                  </Link>
                </li>
              ))}
              <li>
                <Link 
                  href="/sitemap" 
                  className="text-sm text-gray-400 hover:text-primary transition-colors"
                >
                  Sitemap
                </Link>
              </li>
              <li>
                <Link 
                  href="https://www.thepitchlabonline.com/" 
                  target="_blank" 
                  rel="noopener noreferrer" 
                  className="text-sm text-gray-400 hover:text-primary transition-colors"
                >
                  made by Pitch
                </Link>
              </li>
            </ul>
          </div>
        </div>

        <Separator className="my-8" />

        <div className="text-sm text-gray-500 space-y-2">
          <p>© {new Date().getFullYear()} {COMPANY_NAME}. All rights reserved. BJ McKenna is part of the McHale Group with multiple office locations offering full-service support</p>
          <p>© BJ McKenna & Co Solicitors 2008 - 2025 - Solicitors Stockport, Heaton Chapel, Heaton Mersey, Reddish, Offerton & Marple</p>
          <p>B J McKenna & Co Solicitors is a trading name of B J McKenna & Co Solicitors LLP. The term partner is used to refer to a member of the LLP.</p>
          <p>B J McKenna & Co Solicitors LLP is a Limited Liability Partnership registered in England and Wales Number OC376377.</p>
          <p>Registered office: 335 Wellington Road North, Heaton Chapel, Stockport, SK4 4QG where a list of members of the LLP is available for inspection.</p>
          <p>​Authorised and regulated by the Solicitors Regulation Authority www.sra.org.uk SRA Number: 570089.</p>
        </div>
      </div>
    </footer>
  );
}